summary refs log tree commit diff
path: root/synapse/rest
diff options
context:
space:
mode:
authorEric Eastwood <erice@element.io>2021-09-21 08:10:01 -0500
committerGitHub <noreply@github.com>2021-09-21 14:10:01 +0100
commitee557b5375e376e5664f6a3e372c946f7a754f75 (patch)
treeefc2570b2d61350f8ae8061b84cbb40848e638a7 /synapse/rest
parentMerge tag 'v1.43.0' into develop (diff)
downloadsynapse-ee557b5375e376e5664f6a3e372c946f7a754f75.tar.xz
Rename `/batch_send` query parameter from `?prev_event` to more obvious usage with `?prev_event_id` (MSC2716) (#10839)
As mentioned in https://github.com/matrix-org/matrix-doc/pull/2716#discussion_r705872887
and https://github.com/matrix-org/synapse/issues/10737
Diffstat (limited to 'synapse/rest')
-rw-r--r--synapse/rest/client/room_batch.py16
1 files changed, 9 insertions, 7 deletions
diff --git a/synapse/rest/client/room_batch.py b/synapse/rest/client/room_batch.py
index d466edeec2..f73ccc7f65 100644
--- a/synapse/rest/client/room_batch.py
+++ b/synapse/rest/client/room_batch.py
@@ -61,7 +61,7 @@ class RoomBatchSendEventRestServlet(RestServlet):
     some messages, you can only insert older ones after that.
     tldr; Insert chunks from your most recent history -> oldest history.
 
-    POST /_matrix/client/unstable/org.matrix.msc2716/rooms/<roomID>/batch_send?prev_event=<eventID>&chunk_id=<chunkID>
+    POST /_matrix/client/unstable/org.matrix.msc2716/rooms/<roomID>/batch_send?prev_event_id=<eventID>&chunk_id=<chunkID>
     {
         "events": [ ... ],
         "state_events_at_start": [ ... ]
@@ -188,24 +188,26 @@ class RoomBatchSendEventRestServlet(RestServlet):
         assert_params_in_dict(body, ["state_events_at_start", "events"])
 
         assert request.args is not None
-        prev_events_from_query = parse_strings_from_args(request.args, "prev_event")
+        prev_event_ids_from_query = parse_strings_from_args(
+            request.args, "prev_event_id"
+        )
         chunk_id_from_query = parse_string(request, "chunk_id")
 
-        if prev_events_from_query is None:
+        if prev_event_ids_from_query is None:
             raise SynapseError(
                 HTTPStatus.BAD_REQUEST,
                 "prev_event query parameter is required when inserting historical messages back in time",
                 errcode=Codes.MISSING_PARAM,
             )
 
         # For the event we are inserting next to (`prev_events_from_query`),
         # find the most recent auth events (derived from state events) that
         # allowed that message to be sent. We will use that as a base
         # to auth our historical messages against.
         (
             most_recent_prev_event_id,
             _,
-        ) = await self.store.get_max_depth_of(prev_events_from_query)
+        ) = await self.store.get_max_depth_of(prev_event_ids_from_query)
         # mapping from (type, state_key) -> state_event_id
         prev_state_map = await self.state_store.get_state_ids_for_event(
             most_recent_prev_event_id
@@ -286,7 +288,7 @@ class RoomBatchSendEventRestServlet(RestServlet):
         events_to_create = body["events"]
 
         inherited_depth = await self._inherit_depth_from_prev_ids(
-            prev_events_from_query
+            prev_event_ids_from_query
         )
 
         # Figure out which chunk to connect to. If they passed in
@@ -321,7 +323,7 @@ class RoomBatchSendEventRestServlet(RestServlet):
         # an insertion event), in which case we just create a new insertion event
         # that can then get pointed to by a "marker" event later.
         else:
-            prev_event_ids = prev_events_from_query
+            prev_event_ids = prev_event_ids_from_query
 
             base_insertion_event_dict = self._create_insertion_event_dict(
                 sender=requester.user.to_string(),
@@ -188,24 +188,26 @@ class RoomBatchSendEventRestServlet(RestServlet):
             )
 
-        # For the event we are inserting next to (`prev_events_from_query`),
+        # For the event we are inserting next to (`prev_event_ids_from_query`),
         # find the most recent auth events (derived from state events) that
         # allowed that message to be sent. We will use that as a base